@@ -1,16 +1,28 @@
 // Powder Diffraction CIF (pdCIF)
 // Licence: Lesser GNU Public License 2.1 (LGPL)
-// $Id: pdcif.cpp 704 2010-10-26 18:36:25Z wojdyr $
 
 #define BUILDING_XYLIB
 #include "pdcif.h"
 
 #include <map>
-
 //#define BOOST_SPIRIT_DEBUG
+#include <boost/version.hpp>
+
+#if BOOST_VERSION >= 103800
+
+#include <boost/spirit/include/classic_core.hpp>
+#include <boost/spirit/include/classic_chset.hpp>
+#include <boost/spirit/include/classic_increment_actor.hpp>
+using namespace boost::spirit::classic;
+
+#else
+
 #include <boost/spirit/core.hpp>
 #include <boost/spirit/utility/chset.hpp>
 #include <boost/spirit/actor/increment_actor.hpp>
+using namespace boost::spirit;
+
+#endif
 
 #include "util.h"
 
@@ -19,7 +31,6 @@
 #endif
 
 using namespace std;
-using namespace boost::spirit;
 using namespace xylib::util;
 
 namespace xylib {
@@ -34,7 +45,7 @@ const FormatInfo PdCifDataSet::fmt_info(
     &PdCifDataSet::check
 );
 
-bool PdCifDataSet::check(istream &f)
+bool PdCifDataSet::check(istream &f, string*)
 {
     string line;
     // the 1st line (that is not a comment) must start with "data_"
